.. currentmodule:: sardana.test
.. _sardana-test-api:

===================
Sardana test API
===================

Macro test API
----------------------

.. automodule:: sardana.macroserver.macros.test
.. rubric:: Classes

.. hlist::
    :columns: 3

    * :class:`.BaseMacroExecutor`
    * :class:`.MacroExecutorFactory`
    * :class:`.BaseMacroTestCase`
    * :class:`.RunMacroTestCase`
    * :class:`.RunStopMacroTestCase`
    * :class:`.SarDemoEnv`

Decorator
---------

.. decorator:: macroTest

    .. autofunction:: macroTest



BaseMacroExecutor
-----------------

.. inheritance-diagram:: BaseMacroExecutor
    :parts: 1

.. autoclass:: BaseMacroExecutor
    :inherited-members:
    :members:
    :undoc-members:

MacroExecutorFactory
--------------------

.. inheritance-diagram:: MacroExecutorFactory
    :parts: 1

.. autoclass:: MacroExecutorFactory
    :inherited-members:
    :members:
    :undoc-members:

BaseMacroTestCase
-----------------

.. inheritance-diagram:: BaseMacroTestCase
    :parts: 1

.. autoclass:: BaseMacroTestCase
    :inherited-members:
    :members:
    :undoc-members:

RunMacroTestCase
-----------------

.. inheritance-diagram:: RunMacroTestCase
    :parts: 1

.. autoclass:: RunMacroTestCase
    :inherited-members:
    :members:
    :undoc-members:

RunStopMacroTestCase
---------------------

.. inheritance-diagram:: RunStopMacroTestCase
    :parts: 1

.. autoclass:: RunStopMacroTestCase
    :inherited-members:
    :members:
    :undoc-members:

SarDemoEnv
----------

.. inheritance-diagram:: SarDemoEnv
    :parts: 1

.. autoclass:: SarDemoEnv
    :inherited-members:
    :members:
    :undoc-members:





